# Antifungal Peptide Prediction Tool

This repository hosts the Antifungal Peptide Prediction Tool, a Python package for predicting and analyzing antifungal peptides. It integrates various functionalities including peptide sequence processing, descriptor calculation, and machine learning-based prediction models.

## Installation

To install the package, run the following command:

```bash
# optional: create a virtual environment
pip install virtualenv
virtualenv env --python=python3.8
env\Scripts\activate # activate the virtual environment on Windows
source env/bin/activate # activate the virtual environment on Linux

# install antifungal package with pip
pip install antifungal
```


## Usage
The tool can be used to predict antifungal activities of peptides, as well as rational design, including segment peptide sequences, perform single-point mutation analysis, and globally optimize peptide sequences for enhanced properties.

### Example Usage for antifungal peptide prediction
```python
from antifungal.predict import predict_MIC

seq = ['HIHIRHMWLLR','HIHIRHMWLLRR']
pred = predict_MIC(seq)
print(pred)
# Expected output: 
# {
    # 'antifungal': [True, True],
    # 'prob_antifungal': [95.2, 97.9],
    # 'MIC_C_albicans': [21.8, 17.34],
    # 'prob_MIC_C_albicans': [99.8, 99.8],
    # 'MIC_C_krusei': [7.13, 5.87],
    # 'prob_MIC_C_krusei': [99.3, 99.4],
    # 'MIC_C_neoformans': [24.4, 15.57],
    # 'prob_MIC_C_neoformans': [99.3, 99.6],
    # 'MIC_C_parapsilosis': [18.3, 17.05],
    # 'prob_MIC_C_parapsilosis': [84.5, 82.6],
    # 'AFI': [16.23, 12.82],
    # 'prob_AFI': [79.16, 79.9],
    # 'peptide_seq': ['HIHIRHMWLLR', 'HIHIRHMWLLRR']}
# }
```


### Example Usage for antifungal peptide design
```python
from antifungal.design import segment, single_point_mutation, global_optimization

# Example for segment class
segment_instance = segment("YOUR_PEPTIDE_SEQUENCE")
segment_predictions = segment_instance.get_segmented_sequences().predict()

# Example for single_point_mutation class
mutation_instance = single_point_mutation("YOUR_PEPTIDE_SEQUENCE")
mutation_predictions = mutation_instance.get_mutated_sequences().predict()

# Example for global_optimization class
optimization_instance = global_optimization("YOUR_PEPTIDE_SEQUENCE")
optimized_seq, results = optimization_instance.optimize()
```

## Directory Structure
- **data/**: Contains training data used for model development.
  - **training_data/**: Stores the datasets utilized in training the predictive models.
  - **screening_data**: Stores the screening results in the following article.

- **model/**: Houses the trained models for antifungal peptide prediction.

- **propy/**: Includes a modified version of the propy package, with bug fixes. The original package can be found at PyPI propy.

- **ChemoinfoPy/**: Contains Python scripts for variable selection, peptide sequence preprocessing, descriptor calculation, and dataset partitioning for correction and validation purposes.


## Reference
For more detailed information, refer to the paper [Large-Scale Screening of Antifungal Peptides Based on Quantitative Structure–Activity Relationship, ACS Med. Chem. Lett. 2022, 13, 1, 99–104](https://pubs.acs.org/doi/10.1021/acsmedchemlett.1c00556) and visit the [Antifungal Webserver](https://www.chemoinfolab.com/antifungal).

## License
[MIT](https://choosealicense.com/licenses/mit/)